/*
 * Line6 Linux USB driver - 0.6.5
 *
 * Copyright (C) 2004-2006 Markus Grabner (grabner@icg.tu-graz.ac.at)
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public License as
 *	published by the Free Software Foundation, version 2.
 *
 */

#include "config.h"

#include <sound/driver.h>
#include <sound/core.h>
#include <sound/initval.h>

#include "driver.h"


static int line6_index[SNDRV_CARDS] = SNDRV_DEFAULT_IDX;
static char *line6_id[SNDRV_CARDS] = SNDRV_DEFAULT_STR;


/*
	Initialize the PODxt Pro USB audio system.
*/
int line6_init_audio(struct usb_line6 *line6)
{
	static int dev = 0;
	snd_card_t *card;
	int err;

	card = snd_card_new(line6_index[dev], line6_id[dev], THIS_MODULE, 0);

	if(card == NULL)
		return -ENOMEM;

	line6->card = card;

	strcpy(card->driver, DRIVER_NAME);
	strcpy(card->shortname, "Line6-USB");
	sprintf(card->longname, "Line6 %s at USB %s", line6->devname, line6->msgdev->bus_id);  /* 80 chars - see asound.h */
	
	if((err = line6_init_midi(line6)) < 0)
		return err;

	return 0;
}

/*
	Register the Line6 USB audio system.
*/
int line6_register_audio(struct usb_line6 *line6)
{
	int err;

	if((err = snd_card_register(line6->card)) < 0)
		return err;

	return 0;
}

/*
	Cleanup the PODxt Pro USB audio system.
*/
void line6_cleanup_audio(struct usb_line6 *line6)
{
	snd_card_t *card = line6->card;

	if(card == 0)
		return;

	snd_card_disconnect(card);
	snd_card_free(card);
	line6->card = 0;
}
